@@ -2,11 +2,12 @@ package WWW::Bugzilla::BugTree;
 
 use strict;
 use warnings;
+use Ref::Util qw( is_arrayref );
 use 5.012;
 use Moo;
 
 # ABSTRACT: Fetch a tree of bugzilla bugs blocking a bug
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 
 has ua => (
@@ -73,7 +74,7 @@ sub fetch
   my $dependson = $b->as_hashref->{bug}->{dependson};
   $dependson = [] unless defined $dependson;
   $dependson = [ $dependson ]
-    unless ref $dependson eq 'ARRAY';
+    unless is_arrayref $dependson;
     
   @{ $b->children } = map { $self->fetch($_) } sort @$dependson;
   
@@ -101,7 +102,7 @@ WWW::Bugzilla::BugTree - Fetch a tree of bugzilla bugs blocking a bug
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
