@@ -8,7 +8,7 @@ use XML::Simple qw( XMLin );
 use overload '""' => sub { shift->as_string };
 
 # ABSTRACT: A bug tree returned from WWW::Bugzilla::BugTree
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 
 has url => (
@@ -33,7 +33,7 @@ has as_hashref => (
   init_arg => undef,
   lazy     => 1,
   default  => sub {
-    $DB::single = 1;
+    no warnings;
     XMLin(shift->res->decoded_content);
   },
 );
@@ -79,7 +79,7 @@ WWW::Bugzilla::BugTree::Bug - A bug tree returned from WWW::Bugzilla::BugTree
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 DESCRIPTION
 
